The Geek's Guide To Weddings - When Geeks Wed
Description: Wedding inspiration for geeks, gamers and everyone in-between.

# Sam + Tyler’s Nerf Battle Engagement

- Engagements

Dec 7, 2015

Love is a battlefield in this fun engagement shoot from Ontario based Julius & James so let the Nerf war begin! From the photographer, Julius & James: "Sam and Tyler...

Continue

# Monica + Mark’s Classic Star Trek Engagement

- Engagements

Dec 2, 2015

Live Long and Prosper!

This couple just boldly went there and I love it! From another planet, also known as Three Sisters Volcanoes in New Mexico, Fizelwink Photography, LLC captured these stunning...

Continue

# Brittany + Matt’s Bookworm, Star Wars Wedding

- Weddings

Nov 25, 2015

Book it to the altar for this colorful wedding with gorgeous pictures by Regina as The Photographer, LLC that combines the couple's love for literature and all...

Continue

# Hobbit Inspired Ring Box For Your Precious

- Etsy Finds
- Proposals

Nov 24, 2015

This Hobbit inspired ring box from Etsy shop QuanticLaser is perfect for Tolkien fans to pop THE question. Keep your Precious comfortable in a laser...

Continue

# Karie + Marc’s Secret Star Wars Themed Wedding

- Weddings

Nov 24, 2015

Not only did Karie plan a beautiful wedding on the beach in Hawaii she also surprised her Groom with a Star Wars themed wedding, and Creatrix Photography was...

Continue

# Avengers His and Hers Wedding Cake

- Sweet Treats

Nov 23, 2015

This his and hers themed wedding cake from India's Zoey's Bakehouse is stacked high with Marvel references, pretty wafer paper flowers and topped with a cute bride and...

Continue

# Vicky + Neils’ Awesome Lego and Dinosaur Wedding

- Weddings

Nov 20, 2015

This Lego and dinosaur Summer wedding from Photography by Sophia Lemon features all kinds of geeky goodness you're sure to love from Lego pieces in...

Continue

# Veronica + Kevin’s Star Wars Themed Engagement

- Engagements

Nov 20, 2015

Travel to the lush forest moon of Endor, otherwise known as Hillsborough River State Park in Florida, for some beautiful shots from Darin Crofton Photography of...

Continue

# Vintage Sonic the Hedgehog Wedding Cake

- Sweet Treats

Nov 18, 2015

This half vintage, half Sonic the Hedgehog wedding cake from Uk's award winning Euthymia Cakes features three tiers and a Sonic and Applejack cake topper. Deadpool! What are you...

Continue

# Courtney + Basil’s Magical Harry Potter Themed Wedding

- Weddings

Nov 17, 2015

It's getting cold outside, so wrap yourself up in your favorite house scarf and grab a hot tankard of Butterbeer and enjoy this magical Harry Potter themed...

Continue

#### WGW Community

28,565 Fans
3.6K
2.9K
447
21K

### Storm Inspiration Board

Aug 10, 2015

### Sailor Chibi Moon Inspiration Board

Jan 27, 2015

### Poison Ivy Inspiration Board

Jun 29, 2014

### Frozen Elsa Inspiration Board

Feb 3, 2014

### Finn Adventure Time Inspiration Board

Dec 27, 2013
8 Bit Adventure Time Alice In Wonderland Avengers Back To The Future Batman Captain America Comic Con Comics Cosplay Day Of The Dead Disney Doctor Who Fairy Tales Final Fantasy Game Of Thrones Geeky Valentines Gothic Halloween Harry Potter Hunger Games Indiana Jones Iron Man Lego Lord Of The Rings Mass Effect Minecraft Nightmare Before Christmas Pokemon Portal Punk Rock Robots Star Trek Star Wars Steampunk Super Mario Bros Superhero The Hobbit Tim Burton Transformers Video Games Wonder Woman World of Warcraft Zelda Zombies